<?php

/**
 * Installations Shell
 *
 * web-DPO : Outil de gestion de vos traitements dans le cadre de la
 * réglementation relative à la protection des données personnelles (RGPD)
 *
 * Copyright (c) Libriciel SCOP (https://www.libriciel.fr/)
 *
 * Licensed under the GNU Affero General Public License version 3 License - AGPL v3
 * For full copyright and license information, please see the "LICENSE" file.
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright   Copyright (c) Libriciel SCOP (https://www.libriciel.fr/)
 * @link        https://www.libriciel.fr/web-dpo/
 * @since       web-DPO v1.0.0
 * @license     [GNU Affero General Public License version 3](http://www.gnu.org/licenses/agpl-3.0.html) - AGPL v3
 * @version     v2.1.0
 * @package     App.Console.Command.Shell
 */

class UpdateLigneFormulaireShell extends Shell {

    public $uses = [
        'Formulaire',
        'Champ'
    ];


    public function getOptionParser(): ConsoleOptionParser
    {
        $parser = parent::getOptionParser();

        $parser->description([
            'Recalcule position champ dans la meme colonne',
            '',
            '',
        ]);

        $options = [
            'formulaireId' => [
                'help' => "Id du formulaire",
                'default' => null,
                'required' => true,
            ],
            'colonne' => [
                'help' => "Numéro de colonne 1 ou 2",
                'default' => 1,
                'required' => true,
            ]
        ];
        $parser->addOptions($options);

        return $parser;
    }

    public function updateForm()
    {
        $formulaire_id = Hash::get($this->params, 'formulaireId');
        $colonne = Hash::get($this->params, 'colonne');

        $success = true;
        $this->Champ->begin();

        $formChamps = $this->Champ->find('all', [
            'conditions' => [
                'formulaire_id' => $formulaire_id,
                'colonne' => $colonne,
                'champ_coresponsable' => false,
                'champ_soustraitant' => false,
            ],
            'fields' => [
                'id',
                'ligne',
                'type',
            ],
            'order' => 'ligne'
        ]);

        foreach ($formChamps as $key => $formChamp) {
            if ($key === 0) {
                continue;
            }

            if ($formChamps[$key-1]['Champ']['type'] === 'date' ||
                $formChamps[$key-1]['Champ']['type'] === 'input' ||
                $formChamps[$key-1]['Champ']['type'] === 'texte' ||
                $formChamps[$key-1]['Champ']['type'] === 'title'
            ) {
                if ($formChamp['Champ']['ligne'] - $formChamps[$key - 1]['Champ']['ligne'] < 2) {
                    $formChamps[$key]['Champ']['ligne'] = $formChamps[$key - 1]['Champ']['ligne'] + 2;
                }
            }

            if ($formChamps[$key-1]['Champ']['type'] === 'textarea' ||
                $formChamps[$key-1]['Champ']['type'] === 'checkboxes' ||
                $formChamps[$key-1]['Champ']['type'] === 'radios'
            ) {
                if ($formChamp['Champ']['ligne'] - $formChamps[$key - 1]['Champ']['ligne'] < 5) {
                    $formChamps[$key]['Champ']['ligne'] = $formChamps[$key - 1]['Champ']['ligne'] + 5;
                }
            }
        }

//        foreach ($formChamps as $key => $formChamp) {
//            if ($key === 0) {
//                continue;
//            }
//
//            if ($formChamp['Champ']['type'] === 'date' ||
//                $formChamp['Champ']['type'] === 'input' ||
//                $formChamp['Champ']['type'] === 'texte'
//            ) {
//                //ecart de 2
//                if ($formChamp['Champ']['ligne'] - $formChamps[$key - 1]['Champ']['ligne'] < 2) {
//                    $formChamps[$key]['Champ']['ligne'] = $formChamps[$key - 1]['Champ']['ligne'] + 2;
//
//                    //update caleur de results[$key -1]
//                }
//                continue;
//            }
//
//            if ($formChamp['Champ']['type'] === 'title' ||
//                $formChamp['Champ']['type'] === 'radios' ||
//                $formChamp['Champ']['type'] === 'textarea' ||
//                $formChamp['Champ']['type'] === 'checkboxes'
//            ) {
//                //ecart de 5
//                if ($formChamp['Champ']['ligne'] - $formChamps[$key - 1]['Champ']['ligne'] < 5) {
//                    $formChamps[$key]['Champ']['ligne'] = $formChamps[$key - 1]['Champ']['ligne'] + 5;
//                }
//            }
//
//        }

        foreach ($formChamps as $formChamp) {
            $this->Champ->create($formChamp);
            $success = false !== $this->Champ->save(null, ['atomic' => false]);
        }

        if ($success === true) {
            $this->Champ->commit();
        } else {
            $this->Champ->rollback();
        }
    }
}